@@ -7,7 +7,9 @@ Demonstrates using ``ax.voxels`` with uneven coordinates
 '''
 import matplotlib.pyplot as plt
 import numpy as np
-from mpl_toolkits.mplot3d import Axes3D
+
+# This import registers the 3D projection, but is otherwise unused.
+from mpl_toolkits.mplot3d import Axes3D  # noqa: F401 unused import
 
 
 def explode(data):
