@@ -1,14 +1,11 @@
-from matplotlib.backend_bases import FigureCanvasBase
-from matplotlib.backend_bases import RendererBase
-
+from matplotlib.backend_bases import (
+    FigureCanvasBase, LocationEvent, RendererBase)
 import matplotlib.pyplot as plt
 import matplotlib.transforms as transforms
 import matplotlib.path as path
-
-import numpy as np
 import os
-import shutil
-import tempfile
+import numpy as np
+import pytest
 
 
 def test_uses_per_path():
@@ -50,30 +47,49 @@ def test_uses_per_path():
     check(id, paths, tforms, offsets, facecolors[0:1], edgecolors)
 
 
-def test_get_default_filename():
-    try:
-        test_dir = tempfile.mkdtemp()
-        plt.rcParams['savefig.directory'] = test_dir
-        fig = plt.figure()
-        canvas = FigureCanvasBase(fig)
-        filename = canvas.get_default_filename()
-        assert filename == 'image.png'
-    finally:
-        shutil.rmtree(test_dir)
+def test_get_default_filename(tmpdir):
+    plt.rcParams['savefig.directory'] = str(tmpdir)
+    fig = plt.figure()
+    canvas = FigureCanvasBase(fig)
+    filename = canvas.get_default_filename()
+    assert filename == 'image.png'
 
 
-def test_get_default_filename_already_exists():
-    # From #3068: Suggest non-existing default filename
-    try:
-        test_dir = tempfile.mkdtemp()
-        plt.rcParams['savefig.directory'] = test_dir
-        fig = plt.figure()
-        canvas = FigureCanvasBase(fig)
+@pytest.mark.backend('pdf')
+def test_non_gui_warning(monkeypatch):
+    plt.subplots()
 
-        # create 'image.png' in figure's save dir
-        open(os.path.join(test_dir, 'image.png'), 'w').close()
+    monkeypatch.setitem(os.environ, "DISPLAY", ":999")
 
-        filename = canvas.get_default_filename()
-        assert filename == 'image-1.png'
-    finally:
-        shutil.rmtree(test_dir)
+    with pytest.warns(UserWarning) as rec:
+        plt.show()
+        assert len(rec) == 1
+        assert ('Matplotlib is currently using pdf, which is a non-GUI backend'
+                in str(rec[0].message))
+
+    with pytest.warns(UserWarning) as rec:
+        plt.gcf().show()
+        assert len(rec) == 1
+        assert ('Matplotlib is currently using pdf, which is a non-GUI backend'
+                in str(rec[0].message))
+
+
+def test_location_event_position():
+    # LocationEvent should cast its x and y arguments
+    # to int unless it is None
+    fig = plt.figure()
+    canvas = FigureCanvasBase(fig)
+    test_positions = [(42, 24), (None, 42), (None, None),
+                      (200, 100.01), (205.75, 2.0)]
+    for x, y in test_positions:
+        event = LocationEvent("test_event", canvas, x, y)
+        if x is None:
+            assert event.x is None
+        else:
+            assert event.x == int(x)
+            assert isinstance(event.x, int)
+        if y is None:
+            assert event.y is None
+        else:
+            assert event.y == int(y)
+            assert isinstance(event.y, int)
