@@ -7,8 +7,9 @@ How to create grid-shaped combinations of axes.
 
     :func:`~matplotlib.pyplot.subplots`
         Perhaps the primary function used to create figures and axes.
-        It's also similar to :func:`~matplotlib.pyplot.subplot`,
-        but creates and places all axes on the figure at once.
+        It's also similar to :func:`.matplotlib.pyplot.subplot`,
+        but creates and places all axes on the figure at once.  See also
+        `matplotlib.Figure.subplots`.
 
     :class:`~matplotlib.gridspec.GridSpec`
         Specifies the geometry of the grid that a subplot will be
@@ -20,12 +21,14 @@ How to create grid-shaped combinations of axes.
         Specifies the location of the subplot in the given *GridSpec*.
 
     :func:`~matplotlib.pyplot.subplot2grid`
-        A helper function that is similar to :func:`~matplotlib.pyplot.subplot`,
+        A helper function that is similar to
+        :func:`~matplotlib.pyplot.subplot`,
         but uses 0-based indexing and let subplot to occupy multiple cells.
         This function is not covered in this tutorial.
 
 """
 
+import matplotlib
 import matplotlib.pyplot as plt
 import matplotlib.gridspec as gridspec
 
@@ -33,15 +36,14 @@ import matplotlib.gridspec as gridspec
 # Basic Quickstart Guide
 # ======================
 #
-# These first two examples show how to create a basic 4-by-4 grid using
+# These first two examples show how to create a basic 2-by-2 grid using
 # both :func:`~matplotlib.pyplot.subplots` and :mod:`~matplotlib.gridspec`.
 #
 # Using :func:`~matplotlib.pyplot.subplots` is quite simple.
 # It returns a :class:`~matplotlib.figure.Figure` instance and an array of
 # :class:`~matplotlib.axes.Axes` objects.
 
-fig1, f1_axes = plt.subplots(ncols=2, nrows=2)
-fig1.tight_layout()
+fig1, f1_axes = plt.subplots(ncols=2, nrows=2, constrained_layout=True)
 
 ############################################################################
 # For a simple use case such as this, :mod:`~matplotlib.gridspec` is
@@ -53,36 +55,58 @@ fig1.tight_layout()
 # The elements of the gridspec are accessed in generally the same manner as
 # numpy arrays.
 
-fig2 = plt.figure()
-spec2 = gridspec.GridSpec(ncols=2, nrows=2)
+fig2 = plt.figure(constrained_layout=True)
+spec2 = gridspec.GridSpec(ncols=2, nrows=2, figure=fig2)
 f2_ax1 = fig2.add_subplot(spec2[0, 0])
 f2_ax2 = fig2.add_subplot(spec2[0, 1])
 f2_ax3 = fig2.add_subplot(spec2[1, 0])
 f2_ax4 = fig2.add_subplot(spec2[1, 1])
-fig2.tight_layout()
 
 #############################################################################
-# When you want to have subplots of different sizes, however,
-# :mod:`~matplotlib.gridspec` becomes indispensable and provides a couple
-# of options.
-# The method shown here initializes a uniform grid specification,
-# and then uses typical numpy indexing and slices to allocate multiple
+# The power of gridspec comes in being able to create subplots that span
+# rows and columns.  Note the
+# `Numpy slice <https://docs.scipy.org/doc/numpy/reference/arrays.indexing.html>`_
+# syntax for selecing the part of the gridspec each subplot will occupy.
+#
+# Note that we have also used the convenience method `.Figure.add_gridspec`
+# instead of `.gridspec.GridSpec`, potentially saving the user an import,
+# and keeping the namespace cleaner.
+
+fig3 = plt.figure(constrained_layout=True)
+gs = fig3.add_gridspec(3, 3)
+f3_ax1 = fig3.add_subplot(gs[0, :])
+f3_ax1.set_title('gs[0, :]')
+f3_ax2 = fig3.add_subplot(gs[1, :-1])
+f3_ax2.set_title('gs[1, :-1]')
+f3_ax3 = fig3.add_subplot(gs[1:, -1])
+f3_ax3.set_title('gs[1:, -1]')
+f3_ax4 = fig3.add_subplot(gs[-1, 0])
+f3_ax4.set_title('gs[-1, 0]')
+f3_ax5 = fig3.add_subplot(gs[-1, -2])
+f3_ax5.set_title('gs[-1, -2]')
+
+#############################################################################
+# :mod:`~matplotlib.gridspec` is also indispensable for creating subplots
+# of different widths via a couple of methods.
+#
+# The method shown here is similar to the one above and initializes a
+# uniform grid specification,
+# and then uses numpy indexing and slices to allocate multiple
 # "cells" for a given subplot.
 
-fig3 = plt.figure()
-spec3 = gridspec.GridSpec(ncols=3, nrows=3)
+fig4 = plt.figure(constrained_layout=True)
+spec4 = fig4.add_gridspec(ncols=2, nrows=2)
 anno_opts = dict(xy=(0.5, 0.5), xycoords='axes fraction',
                  va='center', ha='center')
 
-fig3.add_subplot(spec3[0, 0]).annotate('GridSpec[0, 0]', **anno_opts)
-fig3.add_subplot(spec3[0, 1:]).annotate('GridSpec[0, 1:]', **anno_opts)
-fig3.add_subplot(spec3[1:, 0]).annotate('GridSpec[1:, 0]', **anno_opts)
-fig3.add_subplot(spec3[1:, 1:]).annotate('GridSpec[1:, 1:]', **anno_opts)
-
-fig3.tight_layout()
+f4_ax1 = fig4.add_subplot(spec4[0, 0])
+f4_ax1.annotate('GridSpec[0, 0]', **anno_opts)
+fig4.add_subplot(spec4[0, 1]).annotate('GridSpec[0, 1:]', **anno_opts)
+fig4.add_subplot(spec4[1, 0]).annotate('GridSpec[1:, 0]', **anno_opts)
+fig4.add_subplot(spec4[1, 1]).annotate('GridSpec[1:, 1:]', **anno_opts)
 
 ############################################################################
-# Other option is to use the ``width_ratios`` and ``height_ratios``
+# Another option is to use the ``width_ratios`` and ``height_ratios``
 # parameters. These keyword arguments are lists of numbers.
 # Note that absolute values are meaningless, only their relative ratios
 # matter. That means that ``width_ratios=[2, 4, 8]`` is equivalent to
@@ -90,19 +114,17 @@ fig3.tight_layout()
 # For the sake of demonstration, we'll blindly create the axes within
 # ``for`` loops since we won't need them later.
 
-fig4 = plt.figure()
+fig5 = plt.figure(constrained_layout=True)
 widths = [2, 3, 1.5]
 heights = [1, 3, 2]
-spec4 = gridspec.GridSpec(ncols=3, nrows=3, width_ratios=widths,
+spec5 = fig5.add_gridspec(ncols=3, nrows=3, width_ratios=widths,
                           height_ratios=heights)
 for row in range(3):
     for col in range(3):
-        ax = fig4.add_subplot(spec4[row, col])
+        ax = fig5.add_subplot(spec5[row, col])
         label = 'Width: {}\nHeight: {}'.format(widths[col], heights[row])
         ax.annotate(label, (0.1, 0.5), xycoords='axes fraction', va='center')
 
-fig4.tight_layout()
-
 ############################################################################
 # Learning to use ``width_ratios`` and ``height_ratios`` is particularly
 # useful since the top-level function :func:`~matplotlib.pyplot.subplots`
@@ -114,28 +136,45 @@ fig4.tight_layout()
 # gridspec instance.
 
 gs_kw = dict(width_ratios=widths, height_ratios=heights)
-fig5, f5_axes = plt.subplots(ncols=3, nrows=3, gridspec_kw=gs_kw)
-for r, row in enumerate(f5_axes):
+fig6, f6_axes = plt.subplots(ncols=3, nrows=3, constrained_layout=True,
+        gridspec_kw=gs_kw)
+for r, row in enumerate(f6_axes):
     for c, ax in enumerate(row):
         label = 'Width: {}\nHeight: {}'.format(widths[c], heights[r])
         ax.annotate(label, (0.1, 0.5), xycoords='axes fraction', va='center')
 
-fig5.tight_layout()
+############################################################################
+# The ``subplots`` and ``gridspec`` methods can be combined since it is
+# sometimes more convenient to make most of the subplots using ``subplots``
+# and then remove some and combine them.  Here we create a layout with
+# the bottom two axes in the last column combined.
 
+fig7, f7_axs = plt.subplots(ncols=3, nrows=3)
+gs = f7_axs[1, 2].get_gridspec()
+# remove the underlying axes
+for ax in f7_axs[1:, -1]:
+    ax.remove()
+axbig = fig7.add_subplot(gs[1:, -1])
+axbig.annotate('Big Axes \nGridSpec[1:, -1]', (0.1, 0.5),
+               xycoords='axes fraction', va='center')
+
+fig7.tight_layout()
 
 ###############################################################################
 # Fine Adjustments to a Gridspec Layout
 # =====================================
 #
 # When a GridSpec is explicitly used, you can adjust the layout
-# parameters of subplots that are created from the GridSpec.
-
-fig = plt.figure()
-gs1 = gridspec.GridSpec(nrows=3, ncols=3, left=0.05, right=0.48, wspace=0.05)
-ax1 = fig.add_subplot(gs1[:-1, :])
-ax2 = fig.add_subplot(gs1[-1, :-1])
-ax3 = fig.add_subplot(gs1[-1, -1])
+# parameters of subplots that are created from the GridSpec.  Note this
+# option is not compatible with ``constrained_layout`` or
+# `.Figure.tight_layout` which both adjust subplot sizes to fill the
+# figure.
 
+fig8 = plt.figure(constrained_layout=False)
+gs1 = fig8.add_gridspec(nrows=3, ncols=3, left=0.05, right=0.48, wspace=0.05)
+f8_ax1 = fig8.add_subplot(gs1[:-1, :])
+f8_ax2 = fig8.add_subplot(gs1[-1, :-1])
+f8_ax3 = fig8.add_subplot(gs1[-1, -1])
 
 ###############################################################################
 # This is similar to :func:`~matplotlib.pyplot.subplots_adjust`, but it only
@@ -143,19 +182,18 @@ ax3 = fig.add_subplot(gs1[-1, -1])
 #
 # For example, compare the left and right sides of this figure:
 
-fig = plt.figure()
-gs1 = gridspec.GridSpec(nrows=3, ncols=3, left=0.05, right=0.48,
+fig9 = plt.figure(constrained_layout=False)
+gs1 = fig9.add_gridspec(nrows=3, ncols=3, left=0.05, right=0.48,
                         wspace=0.05)
-ax1 = fig.add_subplot(gs1[:-1, :])
-ax2 = fig.add_subplot(gs1[-1, :-1])
-ax3 = fig.add_subplot(gs1[-1, -1])
+f9_ax1 = fig9.add_subplot(gs1[:-1, :])
+f9_ax2 = fig9.add_subplot(gs1[-1, :-1])
+f9_ax3 = fig9.add_subplot(gs1[-1, -1])
 
-
-gs2 = gridspec.GridSpec(nrows=3, ncols=3, left=0.55, right=0.98,
+gs2 = fig9.add_gridspec(nrows=3, ncols=3, left=0.55, right=0.98,
                         hspace=0.05)
-ax4 = fig.add_subplot(gs2[:, :-1])
-ax5 = fig.add_subplot(gs2[:-1, -1])
-ax6 = fig.add_subplot(gs2[-1, -1])
+f9_ax4 = fig9.add_subplot(gs2[:, :-1])
+f9_ax5 = fig9.add_subplot(gs2[:-1, -1])
+f9_ax6 = fig9.add_subplot(gs2[-1, -1])
 
 ###############################################################################
 # GridSpec using SubplotSpec
@@ -164,19 +202,20 @@ ax6 = fig.add_subplot(gs2[-1, -1])
 # You can create GridSpec from the :class:`~matplotlib.gridspec.SubplotSpec`,
 # in which case its layout parameters are set to that of the location of
 # the given SubplotSpec.
+#
+# Note this is also available from the more verbose
+# `.gridspec.GridSpecFromSubplotSpec`.
 
-fig = plt.figure()
-gs0 = gridspec.GridSpec(1, 2)
+fig10 = plt.figure(constrained_layout=True)
+gs0 = fig10.add_gridspec(1, 2)
 
-gs00 = gridspec.GridSpecFromSubplotSpec(2, 3, subplot_spec=gs0[0])
-gs01 = gridspec.GridSpecFromSubplotSpec(3, 2, subplot_spec=gs0[1])
+gs00 = gs0[0].subgridspec(2, 3)
+gs01 = gs0[1].subgridspec(3, 2)
 
 for a in range(2):
     for b in range(3):
-        fig.add_subplot(gs00[a, b])
-        fig.add_subplot(gs01[b, a])
-
-fig.tight_layout()
+        fig10.add_subplot(gs00[a, b])
+        fig10.add_subplot(gs01[b, a])
 
 ###############################################################################
 # A Complex Nested GridSpec using SubplotSpec
@@ -193,23 +232,23 @@ from itertools import product
 def squiggle_xy(a, b, c, d, i=np.arange(0.0, 2*np.pi, 0.05)):
     return np.sin(i*a)*np.cos(i*b), np.sin(i*c)*np.cos(i*d)
 
-fig = plt.figure(figsize=(8, 8))
+
+fig11 = plt.figure(figsize=(8, 8), constrained_layout=False)
 
 # gridspec inside gridspec
-outer_grid = gridspec.GridSpec(4, 4, wspace=0.0, hspace=0.0)
+outer_grid = fig11.add_gridspec(4, 4, wspace=0.0, hspace=0.0)
 
 for i in range(16):
-    inner_grid = gridspec.GridSpecFromSubplotSpec(
-      3, 3, subplot_spec=outer_grid[i], wspace=0.0, hspace=0.0)
+    inner_grid = outer_grid[i].subgridspec(3, 3, wspace=0.0, hspace=0.0)
     a, b = int(i/4)+1, i % 4+1
     for j, (c, d) in enumerate(product(range(1, 4), repeat=2)):
-        ax = plt.Subplot(fig, inner_grid[j])
+        ax = plt.Subplot(fig11, inner_grid[j])
         ax.plot(*squiggle_xy(a, b, c, d))
         ax.set_xticks([])
         ax.set_yticks([])
-        fig.add_subplot(ax)
+        fig11.add_subplot(ax)
 
-all_axes = fig.get_axes()
+all_axes = fig11.get_axes()
 
 # show only the outside spines
 for ax in all_axes:
@@ -225,3 +264,19 @@ for ax in all_axes:
         ax.spines['right'].set_visible(True)
 
 plt.show()
+
+#############################################################################
+#
+# ------------
+#
+# References
+# """"""""""
+#
+# The usage of the following functions and methods is shown in this example:
+
+matplotlib.pyplot.subplots
+matplotlib.figure.Figure.add_gridspec
+matplotlib.figure.Figure.add_subplot
+matplotlib.gridspec.GridSpec
+matplotlib.gridspec.SubplotSpec.subgridspec
+matplotlib.gridspec.GridSpecFromSubplotSpec
